@@ -211,6 +211,14 @@ QPoint qt_gnuplotCoord(int x, int y)
 	return QPoint(x*qt_oversampling, int(term->ymax) - y*qt_oversampling);
 }
 
+#ifndef GNUPLOT_QT
+# ifdef WIN32
+#  define GNUPLOT_QT "gnuplot_qt.exe"
+# else
+#  define GNUPLOT_QT "gnuplot_qt"
+# endif
+#endif
+
 // Start the GUI application
 void execGnuplotQt()
 {
@@ -218,22 +226,23 @@ void execGnuplotQt()
 	char* path = getenv("GNUPLOT_DRIVER_DIR");
 	if (path)
 		filename = QString(path);
+	if (filename.isEmpty()) {
 #ifdef WIN32
-	if (filename.isEmpty())
 		filename = QCoreApplication::applicationDirPath();
-	filename += "/gnuplot_qt.exe";
 #else
-	if (filename.isEmpty())
 		filename = QT_DRIVER_DIR;
-	filename += "/gnuplot_qt";
 #endif
+	}
+
+	filename += "/";
+	filename += GNUPLOT_QT;
 
 	qint64 pid;
 	qt->gnuplot_qtStarted = QProcess::startDetached(filename, QStringList(), QString(), &pid);
 	if (qt->gnuplot_qtStarted)
 		qt->localServerName = "qtgnuplot" + QString::number(pid);
 	else
-		qDebug() << "Could not start gnuplot_qt with path" << filename;
+		fprintf(stderr, "Could not start gnuplot_qt with path %s\n", filename.toUtf8().data());
 }
 
 /*-------------------------------------------------------
@@ -290,14 +299,14 @@ void qt_connectToServer(const QString& server, bool retry = true)
 		// The widget could not be reached: start a gnuplot_qt program which will create a QtGnuplotApplication
 		if (connectToWidget)
 		{
-			qDebug() << "Could not connect to widget" << qt_option->Widget << ". Starting a QtGnuplotApplication";
+			fprintf(stderr, "Could not connect to existing qt widget. Starting a new one.\n");
 			qt_option->Widget = QString();
 			qt_connectToServer(qt->localServerName);
 		}
 		// The gnuplot_qt program could not be reached: try to start a new one
 		else
 		{
-			qDebug() << "Could not connect to gnuplot_qt" << server << ". Starting a new one";
+			fprintf(stderr, "Could not connect to existing gnuplot_qt. Starting a new one.\n");
 			execGnuplotQt();
 			qt_connectToServer(qt->localServerName, false);
 		}
@@ -349,7 +358,7 @@ bool qt_processTermEvent(gp_event_t* event)
 		// This is an answer to a font metric request. We don't send it back to gnuplot
 		if ((event->par1 > 0) && (event->par2 > 0))
 		{
-			qDebug() << "qt_processTermEvent received a GE_fontprops event. This should not have happened";
+			fprintf(stderr, "qt_processTermEvent received a GE_fontprops event. This should not have happened\n");
 			return false;
 		}
 		// This is a resize event
@@ -929,8 +938,12 @@ int qt_waitforinput(int options)
 	int stdin_fd  = fileno(stdin);
 	int socket_fd = qt ? qt->socket.socketDescriptor() : -1;
 
-	if (!qt || (socket_fd < 0) || (qt->socket.state() != QLocalSocket::ConnectedState))
-		return (options == TERM_ONLY_CHECK_MOUSING) ? '\0' : getchar();
+	if (!qt || (socket_fd < 0) || (qt->socket.state() != QLocalSocket::ConnectedState)) {
+		if (options == TERM_ONLY_CHECK_MOUSING)
+			return '\0';
+		else
+			return getchar();
+	}
 
 	// Gnuplot event loop
 	do
@@ -966,7 +979,7 @@ int qt_waitforinput(int options)
 		{
 			if (!(qt->socket.waitForReadyRead(-1))) {
 				// Must be a socket error; we need to restart qt_gnuplot
-				qDebug() << "Error: gnuplot_qt socket not responding";
+				fprintf(stderr, "Error: plot window (gnuplot_qt) not responding - will restart\n");
 				qt->gnuplot_qtStarted = false;
 				return '\0';
 			}
@@ -976,7 +989,7 @@ int qt_waitforinput(int options)
 			gp_event_t tempEvent;
 			tempEvent.type = -1;
 			if (qt->socket.bytesAvailable() < (int)sizeof(gp_event_t)) {
-				qDebug() << "Error: short read from gnuplot_qt socket";
+				fprintf(stderr, "Error: short read from gnuplot_qt socket\n");
 				return '\0';
 			}
 			while (qt->socket.bytesAvailable() >= (int)sizeof(gp_event_t))
@@ -1007,7 +1020,12 @@ int qt_waitforinput(int options)
 			return '\0';
 		}
 	} while (paused_for_mouse || !FD_ISSET(stdin_fd, &read_fds));
+
+	if (options == TERM_ONLY_CHECK_MOUSING)
+		return '\0';
+	else
 		return getchar();
+
 #else // Windows console and wgnuplot
 #ifdef WGP_CONSOLE
 	int fd = fileno(stdin);
